addpath /Users/pf/iscmodeling/gwinc/
ifo = IFOModel;
src = SourceModel;
flo = 10;
fhi = 3000;
[ss,nn] = gwinc(flo,fhi,ifo,src,2);
ff = nn.Freq;

%% suspension thermal noise in gwinc is obsolete
%% use M Barton's mathematica model output

mbquadlite2lateral_20090819TM_TN;
tvec = sqrt(xvec.^2 + (1e-3*zvec).^2);
tvec = tvec*2;  % 4 masses
nn.SuspThermalB = interp1(fvec,tvec,ff,[],0);
nn.SuspThermalB = nn.SuspThermalB.^2/(4000^2);  % convert to strain
THnoise = nn.SuspThermalB + nn.MirrorThermal.Total;


T_PRM = 0.03;
NOSRM = [25,   0,          1, 0.014, T_PRM, 120/180*pi]; 
NSNS=   [125, 16/180*pi, 0.2, 0.014, T_PRM, 105/180*pi];
ZERODET=[125,  0       , 0.2, 0.014, T_PRM, 113/180*pi];
ZDETLP =[ 25,  0       , 0.2, 0.014, T_PRM, 103/180*pi];
BHBH20= [ 20, 20/180*pi, 0.2, 0.014, T_PRM, 105/180*pi];
KHZ=    [125,4.7/180*pi,0.011,0.014, 0.027, 128/180*pi];


% mode 0
x = NOSRM;
ifo.Optics.Quadrature.dc=x(6);
[s0,n0] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n0.Total = nn.ResGas + nn.SuspThermalB + n0.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s0 = int73(ff, n0.Total, ifo, src);

% mode 1a
x = ZDETLP;
ifo.Optics.Quadrature.dc=x(6);
[s1a,n1a] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n1a.Total = nn.ResGas + nn.SuspThermalB + n1a.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s1a = int73(ff, n1a.Total, ifo, src);

% mode 1b
x = ZERODET;
ifo.Optics.Quadrature.dc=x(6);
[s1b,n1b] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n1b.Total = nn.ResGas + nn.SuspThermalB + n1b.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s1b = int73(ff, n1b.Total, ifo, src);

% mode 2
x = NSNS;
ifo.Optics.Quadrature.dc=x(6);
[s2,n2] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n2.Total = nn.ResGas + nn.SuspThermalB + n2.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s2 = int73(ff, n2.Total, ifo, src);

% BBH20
x = BHBH20;
ifo.Optics.Quadrature.dc=x(6);
[s3,n3] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));
n3.Total = nn.ResGas + nn.SuspThermalB + n3.Quantum + nn.Newtonian + ...
    nn.Seismic + nn.MirrorThermal.Total;
s3 = int73(ff, n3.Total, ifo, src);

% KHZ
x = KHZ;
ifo.Optics.Quadrature.dc=x(6);
[s4,n4] = gwinc(flo,fhi,ifo,src,4,x(1),x(2),x(3),x(4),x(5));

% make plot
hndls = loglog(ff,sqrt(THnoise),...
    ff,sqrt(n0.Quantum),...
    ff,sqrt(n1a.Quantum),...
    ff,sqrt(n1b.Quantum),...
    ff,sqrt(n2.Quantum),...
    ff,sqrt(n3.Quantum),...
    ff,sqrt(n4.Quantum));

axis([10,3000,1e-24,2e-22]);

lh = legend('Thermal noise', ...
    'Quantum noise, mode 0',...
    'Quantum noise, mode 1a',...
    'Quantum noise, mode 1b',...
    'Quantum noise, mode 2',...
    'Quantum noise, BH-BH mode',...
    'Quantum noise, NB mode');

set(hndls(1:(end)),'LineWidth',4);
set(hndls(1),'color',0.6*[1 1 1]);
set(hndls(2),'color','b');
set(hndls(4),'color','r');
set(hndls(3),'color','r','linestyle','--');
set(hndls(5),'color',0.75*[0 1 1]);
set(hndls(6),'color',0.75*[1 0 1]);
set(hndls(7),'color','k');

lfont = 16;
set(gca,'fontsize',lfont,'fontweight','normal');
xlabel('Frequency (Hz)','fontsize',lfont);
ylabel('Strain noise (Hz^{-1/2})','fontsize',lfont);
set(lh,'fontsize',14,'location','north');

